@@ -545,6 +545,9 @@ static void CG_AddGenericEnt( centity_t *cent )
 	} else {
 		cent->ent.renderfx = cent->renderfx;
 	}
+	if( cent->current.type == ET_GIB ) {
+		cent->ent.renderfx |= RF_NOSHADOW;
+	}
 
 	if( cent->item ) {
 		cent->ent.renderfx |= cent->item->renderfx;
@@ -565,7 +568,7 @@ static void CG_AddGenericEnt( centity_t *cent )
 
 #ifdef CGAMEGETLIGHTORIGIN
 		// add shadows for items (do it before offseting for weapons)
-		if( !(cent->ent.renderfx & RF_NOSHADOW) )
+		if( !(cent->ent.renderfx & RF_NOSHADOW) && (cg_shadows->integer == 1) )
 			CG_AllocShadeBox( cent->current.number, cent->ent.origin, item_box_mins, item_box_maxs, NULL );
 #endif
 
@@ -641,6 +644,10 @@ void CG_AddFlagModelOnTag( centity_t *cent, int flag_team, char *tagname )
 	flag.renderfx = cent->ent.renderfx;
 	flag.customShader = NULL;
 	flag.customSkin = NULL;
+	flag.shaderRGBA[0] = ( qbyte )( 255 * teamcolor[0] );
+	flag.shaderRGBA[1] = ( qbyte )( 255 * teamcolor[1] );
+	flag.shaderRGBA[2] = ( qbyte )( 255 * teamcolor[2] );
+	flag.shaderRGBA[3] = ( qbyte )( 255 * teamcolor[3] );
 	if( cent->ent.renderfx & RF_VIEWERMODEL ) {
 		VectorCopy( cg.refdef.vieworg, flag.origin );
 		VectorCopy( cg.refdef.vieworg, flag.origin2 );
@@ -679,11 +686,6 @@ void CG_AddFlagModelOnTag( centity_t *cent, int flag_team, char *tagname )
 			flag.radius = 32.0f;
 			flag.customShader = CG_MediaShader( cgs.media.shaderFlagFlare );
 
-			flag.shaderRGBA[0] = ( qbyte )( 255 * teamcolor[0] );
-			flag.shaderRGBA[1] = ( qbyte )( 255 * teamcolor[1] );
-			flag.shaderRGBA[2] = ( qbyte )( 255 * teamcolor[2] );
-			flag.shaderRGBA[3] = ( qbyte )( 255 * teamcolor[3] );
-
 			CG_AddEntityToScene( &flag );
 		}
 	}
@@ -707,7 +709,17 @@ static void CG_UpdateFlagBaseEnt( centity_t *cent )
 	// start from clean
 	
 	memset( &cent->ent, 0, sizeof( cent->ent ) );
-	Vector4Set( cent->ent.shaderRGBA, 255, 255, 255, 255 );
+	if( cent->current.team <= TEAM_PLAYERS || cent->current.team >= GS_MAX_TEAMS ) {
+		Vector4Set( cent->ent.shaderRGBA, 255, 255, 255, 255 );
+	}
+	else {
+		vec4_t	teamcolor;
+		CG_TeamColor( cent->current.team, teamcolor );
+		cent->ent.shaderRGBA[0] = ( qbyte )( 255 * teamcolor[0] );
+		cent->ent.shaderRGBA[1] = ( qbyte )( 255 * teamcolor[1] );
+		cent->ent.shaderRGBA[2] = ( qbyte )( 255 * teamcolor[2] );
+		cent->ent.shaderRGBA[3] = ( qbyte )( 255 * teamcolor[3] );
+	}
 	cent->ent.scale = 1.0f;
 	cent->ent.renderfx = cent->renderfx;
 
@@ -792,7 +804,6 @@ static void CG_AddFlagBaseEnt( centity_t *cent )
 
 	cent->ent.customSkin = NULL;
 	cent->ent.customShader = NULL;		// never use a custom skin on others
-	Vector4Set( cent->ent.shaderRGBA, 255, 255, 255, 255 );
 
 	// see if we have to add a flag
 	if( cent->effects & EF_ENEMY_FLAG )
@@ -803,6 +814,7 @@ static void CG_AddFlagBaseEnt( centity_t *cent )
 		if( charcount == 1 ) { // we only draw from 9 down
 			static entity_t number;
 			number = cent->ent;
+			Vector4Set( number.shaderRGBA, 255, 255, 255, 255 );
 			number.rtype = RT_SPRITE;
 			number.origin[2] += 24;
 			number.origin2[2] += 24;
@@ -839,7 +851,7 @@ static void CG_AddPlayerEnt( centity_t *cent )
 	}
 
 	// if set to invisible, skip
-	if( !cent->current.modelindex )
+	if( !cent->current.modelindex || cent->current.team == TEAM_SPECTATOR )
 		return;
 
 	CG_AddPModel( cent );
@@ -1035,6 +1047,8 @@ static void CG_AddLaserbeamEnt( centity_t *cent )
 
 	 // was player updated this frame?
 	owner = &cg_entities[ cent->current.ownerNum ];
+	if( owner->current.team == TEAM_SPECTATOR || !owner->current.solid )
+		return;
 
 	if( (cent->current.ownerNum == cg.chasedNum+1) && (owner->serverFrame == cg.frame.serverFrame) )
 	{
@@ -1146,6 +1160,8 @@ static void CG_AddCurveLaserbeamEnt( centity_t *cent )
 
 	// was player updated this frame?
 	owner = &cg_entities[ cent->current.ownerNum ];
+	if( owner->current.team == TEAM_SPECTATOR || !owner->current.solid )
+		return;
 
 	if( (cent->current.ownerNum == cg.chasedNum+1) &&
 		(owner->serverFrame == cg.frame.serverFrame) )
