@@ -1284,15 +1284,46 @@ static int CG_LFuncDrawHelpMessage( struct cg_layoutnode_s *commandnode, struct
 	// hide this one when scoreboard is up
 	if( !(cg.frame.playerState.stats[STAT_LAYOUTS] & STAT_LAYOUT_SCOREBOARD) ) {
 		if( cg_showhelp->integer && !cgs.demoPlaying ) {
-			char *helpmessage = cg.matchmessage;
+			int i;
 			int y = layout_cursor_y;
-			size_t len;
-			while( (len = trap_SCR_DrawStringWidth( layout_cursor_x, y, layout_cursor_align, helpmessage, layout_cursor_width, layout_cursor_font, layout_cursor_color)) )
-			{
-				if( len && helpmessage[len-1] == '\n' ) {
+			char *helpmessage = "";
+
+			for( i = 0; i < 3; i++ ) {
+				size_t len;
+
+				switch( i ) {
+					case 0:
+						helpmessage = (cg.matchmessage ? cg.matchmessage : "");
+						break;
+					case 1:
+						if( !cg.motd )
+							return qtrue;
+						helpmessage = "\nMessage of the Day:";
+						break;
+					case 2:
+						helpmessage = cg.motd;
+						break;
+					default:
+						return qtrue;
+				}
+
+				if( helpmessage[0] ) {
+					do {
+						len = trap_SCR_DrawStringWidth( layout_cursor_x, y, layout_cursor_align, helpmessage, layout_cursor_width, layout_cursor_font, layout_cursor_color);
+						if( !len ) {
+							if( *helpmessage == '\r' || *helpmessage == '\n' )
+								len = 1;
+							else
+								break;
+						}
+						if( helpmessage[len-1] == '\n' ) {
+							y += trap_SCR_strHeight( layout_cursor_font );
+						}
+						helpmessage += len;
+					} while( helpmessage[0] );
+
 					y += trap_SCR_strHeight( layout_cursor_font );
 				}
-				helpmessage += len;
 			}
 		}
 	}
