@@ -1172,7 +1172,7 @@ void CG_SmallPileOfGibs( vec3_t origin, int	count, vec3_t velocity )
 		VectorSet( angles, crandom()*360, crandom()*360, crandom()*360 );
 		AnglesToAxis ( angles, le->ent.axis );
 		le->ent.scale = 1.0 - (crandom()*0.25);
-		le->ent.renderfx = RF_FULLBRIGHT; //jalfixme: needs to fix ligthing
+		le->ent.renderfx = RF_FULLBRIGHT|RF_NOSHADOW; //jalfixme: needs to fix ligthing
 		
 		if( velocity ) {
 			//velocity brought by game + random variations
@@ -1217,6 +1217,7 @@ void CG_EjectBrass( vec3_t origin, int	count, struct model_s *model )
 			0, 0, 0, 0, 
 			model, 
 			NULL );
+		le->ent.renderfx = RF_NOSHADOW;
 
 		//random rotation
 		VectorSet( angles, crandom()*360, crandom()*360, crandom()*360 );
