@@ -547,13 +547,16 @@ typedef struct
 	//
 	// transient data from server
 	//
-	char				layout[MAX_STRING_CHARS];	// general 2D overlay
+	char				*layout;		// general 2D overlay
 	int					inventory[MAX_ITEMS];
 
 	char				checkname[MAX_QPATH];
 	char				loadingstring[MAX_QPATH];
-	char				matchmessage[MAX_STRING_CHARS];
-	char				teaminfo[MAX_STRING_CHARS];
+
+	char				*matchmessage;
+	char				*teaminfo;
+	char				*motd;
+	unsigned int		motd_time;
 
 	// statusbar program
 	struct cg_layoutnode_s *statusBar;
