@@ -1309,9 +1309,9 @@ void CG_AddPModel( centity_t *cent )
 			AnglesToAxis( angles, cent->ent.axis );
 		} else
 			VectorCopy( cent->ent.origin, org );
-
-		// offset it some units back
-		VectorMA( org, -24, cent->ent.axis[0], org );
+		
+		if( cg_shadows->integer == 1 )		// offset it some units back
+			VectorMA( org, -24, cent->ent.axis[0], org );
 		VectorCopy( org, cent->ent.origin);
 		VectorCopy( org, cent->ent.origin2 );
 		VectorCopy( org, cent->ent.lightingOrigin );
@@ -1387,7 +1387,7 @@ void CG_AddPModel( centity_t *cent )
 	if( cg_showPlayerTrails->value )
 		CG_AddLinearTrail( cent, cg_showPlayerTrails->value );
 #ifdef CGAMEGETLIGHTORIGIN
-	if( !(cent->ent.renderfx & RF_NOSHADOW) )
+	if( !(cent->ent.renderfx & RF_NOSHADOW) && (cg_shadows->integer == 1) )
 		CG_AllocShadeBox( cent->current.number, cent->ent.origin, playerbox_stand_mins, playerbox_stand_maxs, NULL );
 #endif
 
