@@ -525,7 +525,7 @@ static void CG_DrawPlayerNames( struct mufont_s *font )
 		if( cent->serverFrame != cg.frame.serverFrame )
 			continue;
 
-		if( !cent->current.modelindex || !cent->current.solid )
+		if( !cent->current.modelindex || !cent->current.solid || cent->current.team == TEAM_SPECTATOR )
 			continue;
 
 		// Kill if behind the view
@@ -705,7 +705,7 @@ void CG_DrawTeamInfo( int x, int y, int align, struct mufont_s *font, vec4_t col
 		return;
 
 	// time to parse the teaminfo string
-	if( !strlen(cg.teaminfo) )
+	if( !cg.teaminfo )
 		return;
 
 	height = trap_SCR_strHeight( font );
@@ -820,7 +820,12 @@ void CG_DrawTeamInfo( int x, int y, int align, struct mufont_s *font, vec4_t col
 //================
 void CG_LoadLayout( char *s ) 
 {
-	Q_strncpyz( cg.layout, s, sizeof(cg.layout) );
+	if( cg.layout )
+		CG_Free( cg.layout );
+	cg.layout = NULL;
+
+	if( s && *s )
+		cg.layout = CG_CopyString( s );
 }
 
 //================
@@ -1172,7 +1177,8 @@ static void CG_ExecuteLayoutString( char *s )
 			} else if( !Q_stricmp( token, "clock" ) ) {
 				CG_DrawClock( x, y, align, cgs.fontSystemMedium, flash ? flashColor : color );
 			} else if( !Q_stricmp( token, "match_message" ) && cg_showhelp->integer ) {
-				trap_SCR_DrawString( x, y, align, cg.matchmessage, cgs.fontSystemMedium, flash ? flashColor : color );
+				char *helpmessage = cg.motd ? (cg.matchmessage ? va( "%s\n\n%s", cg.matchmessage, cg.motd ) : cg.motd) : "";
+				trap_SCR_DrawString( x, y, align, helpmessage, cgs.fontSystemMedium, flash ? flashColor : color );
 			} else if( !Q_stricmp( token, "pointing" ) ) {
 				CG_DrawPointed( x, y, align, cgs.fontSystemMedium, flash ? flashColor : color );
 			} else if( !Q_stricmp( token, "stat_string" ) ) {
@@ -1230,7 +1236,8 @@ CG_DrawLayout
 */
 static void CG_DrawLayout( void ) 
 {
-	CG_ExecuteLayoutString( cg.layout );
+	if( cg.layout )
+		CG_ExecuteLayoutString( cg.layout );
 }
 
 /*
@@ -1417,6 +1424,11 @@ void CG_Draw2D( void )
 #endif
 	CG_SCRDrawViewBlend();
 
+	if( cg.motd && (cg.time > cg.motd_time) ) {
+		CG_Free( cg.motd );
+		cg.motd = NULL;
+	}
+
 	if( cg_clientHUD->modified ) {
 		CG_LoadStatusBar();
 		cg_clientHUD->modified = qfalse;
