@@ -59,9 +59,6 @@ cvar_t	*m_side;
 //
 cvar_t	*info_password;
 cvar_t	*rate;
-#ifdef BATTLEYE
-cvar_t	*cl_battleye;
-#endif
 
 cvar_t	*cl_masterservers;
 
@@ -70,13 +67,11 @@ cvar_t	*cl_debug_serverCmd;
 
 cvar_t	*cl_downloads;
 cvar_t	*cl_downloads_from_web;
+cvar_t	*cl_downloads_from_web_timeout;
 cvar_t	*cl_checkForUpdate;
 
 client_static_t	cls;
 client_state_t	cl;
-#ifdef BATTLEYE
-client_battleye_t clbe;
-#endif
 
 entity_state_t	cl_baselines[MAX_EDICTS];
 
@@ -109,7 +104,7 @@ void CL_AddReliableCommand( /*const*/ char *cmd ) {
 
 	// if we would be losing an old command that hasn't been acknowledged,
 	// we must drop the connection
-	if ( cls.reliableSequence - cls.reliableAcknowledge > MAX_RELIABLE_COMMANDS ) {
+	if( cls.reliableSequence > cls.reliableAcknowledge + MAX_RELIABLE_COMMANDS ) {
 		cls.reliableAcknowledge = cls.reliableSequence; // try to avoid loops
 		Com_Error( ERR_DROP, "Client command overflow" );
 	}
@@ -1679,22 +1674,12 @@ void CL_SetClientState( int state )
 		case CA_ACTIVE:
 			Con_Close();
 			CL_SetKeyDest( key_game );
+            CL_AddReliableCommand( "svmotd 1" );
 //			SCR_UpdateScreen();
 			break;
 		default:
 			break;
 	}
-
-#ifdef BATTLEYE
-	if( state != CA_ACTIVE )
-	{
-		if( clbe.module )
-		{
-			CL_BE_Unload();
-			MSG_Clear( &cls.be.outMsg );
-		}
-	}
-#endif
 }
 
 /*
@@ -1723,9 +1708,6 @@ void CL_InitMedia( void )
 	// restart renderer
 	R_Restart();
 
-	// free all sounds
-	CL_SoundModule_FreeSounds();
-
 	// register console font and background
 	SCR_RegisterConsoleMedia();
 
@@ -1735,7 +1717,7 @@ void CL_InitMedia( void )
 	// check memory integrity
 	Mem_CheckSentinelsGlobal();
 
-	CL_SoundModule_SoundsInMemory();
+	CL_SoundModule_Init();
 }
 
 /*
@@ -1757,8 +1739,7 @@ void CL_ShutdownMedia( void )
 	CL_UIModule_Shutdown();
 
 	// stop and free all sounds
-	CL_SoundModule_StopAllSounds();
-	CL_SoundModule_FreeSounds();
+	CL_SoundModule_Shutdown();
 
 	// wsw : jalfonts
 	SCR_ShutDownConsoleMedia();
@@ -1784,16 +1765,19 @@ Restart the sound subsystem so it can pick up new parameters and flush all sound
 */
 void CL_S_Restart( qboolean noVideo )
 {
-	CL_SoundModule_Shutdown ();
-	CL_SoundModule_Init ();
-
 	/*
 	Restart the sound subsystem
 	The cgame and game must also be forced to restart because
 	handles will be invalid
+	VID_Restart forces an audio restart
 	*/
 	if( !noVideo )
-		VID_Restart ();
+		VID_Restart();
+	else
+	{
+		CL_SoundModule_Shutdown();
+		CL_SoundModule_Init();
+	}
 }
 /*
 =================
@@ -1846,11 +1830,6 @@ static void CL_InitLocal( void )
 
 	cls.state = CA_DISCONNECTED;
 	Com_SetClientState( CA_DISCONNECTED );
-#ifdef BATTLEYE
-	cls.sv_battleye = qfalse;
-	MSG_Init( &cls.be.outMsg, cls.be.outMsgBuf, sizeof(cls.be.outMsgBuf) );
-	clbe.module = NULL;
-#endif
 
 //
 // register our variables
@@ -1898,6 +1877,7 @@ static void CL_InitLocal( void )
 
 	cl_downloads =			Cvar_Get( "cl_downloads", "1", CVAR_ARCHIVE );
 	cl_downloads_from_web =	Cvar_Get( "cl_downloads_from_web", "1", CVAR_ARCHIVE );
+	cl_downloads_from_web_timeout = Cvar_Get( "cl_downloads_from_web_timeout", "600", CVAR_ARCHIVE );
 	cl_checkForUpdate = 	Cvar_Get( "cl_checkForUpdate", "1", CVAR_ARCHIVE );
 
 	//
@@ -1924,10 +1904,6 @@ static void CL_InitLocal( void )
 		Cvar_Set( "color", va("%i %i %i", (long_time)&0xff, ((long_time)>>8)&0xff, ((long_time)>>16)&0xff) );
 	}
 
-#ifdef BATTLEYE
-	cl_battleye =			Cvar_Get( "cl_battleye", "1", CVAR_USERINFO | CVAR_ARCHIVE );
-#endif
-
 	//
 	// register our commands
 	//
@@ -1960,10 +1936,6 @@ static void CL_InitLocal( void )
 	Cmd_AddCommand( "showserverip", CL_ShowServerIP_f );
 	Cmd_AddCommand( "downloadstatus", CL_DownloadStatus_f );
 	Cmd_AddCommand( "downloadcancel", CL_DownloadCancel_f );
-
-#ifdef BATTLEYE
-	Cmd_AddCommand( "beclient", CL_BEClientCmd_f );
-#endif
 }
 
 /*
@@ -2005,10 +1977,6 @@ static void CL_ShutdownLocal( void )
 	Cmd_RemoveCommand( "showserverip" );
 	Cmd_RemoveCommand( "downloadstatus" );
 	Cmd_RemoveCommand( "downloadcancel" );
-
-#ifdef BATTLEYE
-	Cmd_RemoveCommand( "beclient" );
-#endif
 }
 
 //============================================================================
@@ -2290,14 +2258,6 @@ void CL_SendMessagesToServer( qboolean sendNow )
 		}
 		CL_UpdateClientCommandsToServer( &message );
 		CL_WriteUcmdsToMessage( &message );
-#ifdef BATTLEYE
-		if( clbe.module && cls.be.outMsg.cursize != 0 )
-		{
-			// add BE packets
-			MSG_CopyData( &message, cls.be.outMsg.data, cls.be.outMsg.cursize );
-			MSG_Clear( &cls.be.outMsg );
-		}
-#endif
 		if( message.cursize > 0 )
 			CL_Netchan_Transmit( &message );
 	}
@@ -2374,19 +2334,6 @@ void CL_Frame( int realmsec, int gamemsec )
 	CL_UserInputFrame();
 	CL_NetFrame( realmsec, gamemsec );
 
-#ifdef BATTLEYE
-	// run BattlEye here
-	if( clbe.module )
-	{
-		if( !clbe.Run() )
-		{
-			// reload now
-			CL_BE_Unload();
-			CL_BE_Load();
-		}
-	}
-#endif
-
 	if( cl_maxfps->integer > 0 && !cl_timedemo->integer && !(cls.demoavi && cls.state == CA_ACTIVE) ) {
 		// Vic: do not allow setting cl_maxfps to very low values to prevent cheating
 		// (ultra-high jumps, etc)
@@ -2492,7 +2439,7 @@ static void CL_CheckForUpdate(void)
 	Com_Printf("Checking for Warsow update.\n");
 
 	Q_snprintfz( url, sizeof(url), "%s%s", CHECKUPDATE_URL, CHECKUPDATE_FILE );
-	success = Web_Get( url, NULL, CHECKUPDATE_FILE, qfalse, 2, NULL );
+	success = Web_Get( url, NULL, CHECKUPDATE_FILE, qfalse, 2, 2, NULL );
 
 	if(!success)
 		return;
@@ -2520,16 +2467,23 @@ static void CL_CheckForUpdate(void)
 	// we have the version
 	//Com_Printf("CheckForUpdate: local: %f net: %f\n", local_version, net_version);
 	if(net_version>local_version)
-	{	char cmd[1024];
+	{
+		char cmd[1024];
+		char net_version_str[16], *s;
+
+		Q_snprintfz( net_version_str, sizeof( net_version_str ), "%4.3f", net_version );
+		s = net_version_str + strlen( net_version_str ) - 1;
+		while( *s == '0' ) s--;
+		net_version_str[s-net_version_str+1] = '\0';
 
 		// you should update
-		Com_Printf("Warsow version %4.3f is available.\n", net_version);
-		Q_snprintfz(cmd, 1024, "menu_msgbox \"Version %4.3f of Warsow is available\"", net_version);
-		Cbuf_ExecuteText(EXEC_APPEND, cmd );
+		Com_Printf ("Warsow version %s is available.\n", net_version_str);
+		Q_snprintfz (cmd, 1024, "menu_msgbox \"Version %s of %s is available\"", net_version_str, APPLICATION);
+		Cbuf_ExecuteText (EXEC_APPEND, cmd);
 	}
-	else if(net_version==local_version)
+	else if (net_version == local_version)
 	{
-		Com_Printf("This Warsow version is up-to-date.\n");
+		Com_Printf ("Your %s version is up-to-date.\n", APPLICATION);
 	}
 
 	fclose(f);
