@@ -38,9 +38,6 @@ char *svc_strings[256] =
 	"svc_clcack",
 	"svc_servercs", //tmp jalfixme: sends reliable command as unreliable
 	"svc_frame"
-#ifdef BATTLEYE
-	, "svc_battleye"
-#endif
 };
 
 //=============================================================================
@@ -414,6 +411,7 @@ static void CL_InitDownload_f( void )
 
 	if( cl_downloads_from_web->integer && url && url[0] != 0 )
 	{
+		int			connect_timeout, max_download_time;
 		char		*fulltemp, *referer;
 		qboolean	success;
 
@@ -430,7 +428,9 @@ static void CL_InitDownload_f( void )
 		cls.download.web = qtrue;
 		cls.download.disconnect = qfalse;
 
-		success = Web_Get( url, referer, fulltemp, qtrue, 30, CL_WebDownloadProgress );
+		connect_timeout = 30;
+		max_download_time = cl_downloads_from_web_timeout->integer <= 0 ? 0 : cl_downloads_from_web_timeout->integer;
+		success = Web_Get( url, referer, fulltemp, qtrue, connect_timeout, connect_timeout + max_download_time, CL_WebDownloadProgress );
 
 		cls.download.web = qfalse;
 
@@ -801,11 +801,6 @@ static void CL_ParseServerData( msg_t *msg )
 	CL_RestartMedia();
 
 	cls.sv_pure = (sv_bitflags & SV_BITFLAGS_PURE);
-#ifdef BATTLEYE
-	cls.sv_battleye = (sv_bitflags & SV_BITFLAGS_BATTLEYE);
-	if( !clbe.module && cls.sv_battleye )
-		CL_BE_Load();
-#endif
 
 	// separate the printfs so the server message can have a color
 	Com_Printf( "\n%s\35\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\37\n", S_COLOR_RED );
@@ -978,26 +973,6 @@ ACTION MESSAGES
 =====================================================================
 */
 
-#ifdef BATTLEYE
-static qboolean CL_ParseSVCBattleye( msg_t *msg )
-{
-	size_t len;
-	qbyte packet[MAX_BE_MSGLEN - sizeof(short) - 1];
-
-	len = MSG_ReadShort( msg );
-	if( len <= 0 || len > sizeof(packet) ) {
-		Com_Error( ERR_DROP, "Invalid BattlEye packet size from server" );
-		return qfalse;
-	}
-	MSG_ReadData( msg, packet, len );
-	// pass this packet to BE Client
-	if( !cls.demoplaying )
-		clbe.NewPacket( packet, len );
-
-	return qtrue;
-}
-#endif
-
 void SHOWNET( msg_t *msg, char *s )
 {
 	if (cl_shownet->integer>=2)
@@ -1118,17 +1093,6 @@ void CL_ParseServerMessage( msg_t *msg )
 			CL_ParseFrame( msg );
 			break;
 
-#ifdef BATTLEYE
-		case svc_battleye:
-			if( !clbe.module ) {
-				Com_Error( ERR_DROP, "Invalid command char from server" );
-				return;
-			}
-			if( !CL_ParseSVCBattleye( msg ) )
-				return;
-			break;
-#endif
-
 		case svc_sound:
 		case svc_playerinfo:
 		case svc_packetentities:
