@@ -582,8 +582,8 @@ void SCR_DrawStringLen( int x, int y, int align, const char *str, size_t len, st
 
 	// it fits inside desired len
 	if( screenlen ) {
-		int reallen = s - str + 1;
-		Q_strncpyz( stringLenBuffer, str, reallen );
+		int reallen = s - str;
+		Q_strncpyz( stringLenBuffer, str, reallen+1 );
 		SCR_DrawString( x, y, align, stringLenBuffer, font, color );
 	}
 }
@@ -609,8 +609,8 @@ int SCR_DrawStringWidth( int x, int y, int align, const char *str, int maxwidth,
 	if( !font )
 		font = cls.fontSystemSmall;
 
-	while( curwidth < maxwidth ) {
-		if( !(*s) || *s == '\n' ) { // stop
+	while( curwidth < maxwidth && *s ) {
+		if( *s == '\n' ) { // stop
 			++s;
 			break;
 		}
@@ -632,7 +632,7 @@ int SCR_DrawStringWidth( int x, int y, int align, const char *str, int maxwidth,
 		reallen = s - str;
 		if( reallen >= MAX_DRAWSTRINGLEN_CHARS )
 			reallen = MAX_DRAWSTRINGLEN_CHARS - 1;
-		Q_strncpyz( stringLenBuffer, str, reallen );
+		Q_strncpyz( stringLenBuffer, str, reallen+1 );
 		SCR_DrawString( x, y, align, stringLenBuffer, font, color );
 	}
 
