@@ -80,7 +80,7 @@ keyname_t keynames[] =
 	{"ESCAPE", K_ESCAPE},
 	{"SPACE", K_SPACE},
 	{"CAPSLOCK", K_CAPSLOCK},
-	{"SCROLLLOCK", K_SCROLLLOCK},
+	{"SCROLLOCK", K_SCROLLOCK},
 	{"NUMLOCK", K_NUMLOCK},
 	{"KP_NUMLOCK", K_NUMLOCK},
 	{"BACKSPACE", K_BACKSPACE},
@@ -118,23 +118,23 @@ keyname_t keynames[] =
 //	{"RWINKEY", K_RWIN},
 	{"POPUPMENU", K_MENU},
 
-#if defined (__APPLE__) || defined (MACOSX)
+#if defined(__MACOSX__)
 	{"F13", K_F13},
 	{"F14", K_F14},
 	{"F15", K_F15},
 	{"COMMAND", K_COMMAND},
-#endif /* __APPLE__ || MACOSX */
+#endif /* __MACOSX__ */
 
 	{"MOUSE1", K_MOUSE1},
 	{"MOUSE2", K_MOUSE2},
 	{"MOUSE3", K_MOUSE3},
 	{"MOUSE4", K_MOUSE4},
 	{"MOUSE5", K_MOUSE5},
-#if !defined (__APPLE__) && !defined (MACOSX)
+#if !defined (__MACOSX__)
 	{"MOUSE6", K_MOUSE6},
 	{"MOUSE7", K_MOUSE7},
 	{"MOUSE8", K_MOUSE8},
-#endif /* !__APPLE__ &&!MACOSX */
+#endif /* !__MACOSX__ */
 
 	{"JOY1", K_JOY1},
 	{"JOY2", K_JOY2},
@@ -191,10 +191,10 @@ keyname_t keynames[] =
 	{"KP_MINUS",		KP_MINUS },
 	{"KP_PLUS",			KP_PLUS },
 
-#if defined(__APPLE__) || (MACOSX)
+#if defined(__MACOSX__)
 	{"KP_MULT", KP_MULT},
 	{"KP_EQUAL", KP_EQUAL},
-#endif /* __APPLE__ || MACOSX */
+#endif /* __MACOSX__ */
 
 	{"MWHEELUP", K_MWHEELUP },
 	{"MWHEELDOWN", K_MWHEELDOWN },
