@@ -119,10 +119,17 @@ void G_Teams_UpdateMembersList( void )
 				for( i = 0; i < count; i++ ) {
 					if( !sorted[i] )
 					{
+						int score;
 						ent = game.edicts + list[i];
-						if( match.scores[PLAYERNUM(ent)].score >= bestscore ) {
+						score = match.scores[PLAYERNUM(ent)].score;
+						if( game.gametype == GAMETYPE_TDM )
+							score = match.scores[PLAYERNUM(ent)].kills - match.scores[PLAYERNUM(ent)].teamfrags - match.scores[PLAYERNUM(ent)].deaths; // sort by Net
+						if( game.gametype == GAMETYPE_CA )
+							score = ent->r.client->resp.total_damage_given; // sort by Dmg
+
+						if( score >= bestscore ) {
 							bestplayer = i;
-							bestscore = match.scores[PLAYERNUM(ent)].score;
+							bestscore = score;
 						}
 					}
 				}
@@ -311,6 +318,12 @@ void G_Teams_AssignTeamSkin( edict_t *ent, char *userinfo )
 	char	skin[MAX_QPATH], model[MAX_QPATH];
 	char	*userskin, *usermodel;
 
+	if( ent->s.team == TEAM_SPECTATOR ) {
+		ent->s.modelindex = ent->s.modelindex2 = 0;
+		ent->s.skinnum = 0;
+		return;
+	}
+
 	// index skin file
 	userskin = GS_TeamSkinName( ent->s.team ); // is it a team skin?
 	if( !userskin ) { // NULL indicates *user defined* 
@@ -558,7 +571,11 @@ qboolean G_Teams_JoinTeam( edict_t *ent, int team )
 	G_Teams_SetTeam( ent, team );
 
 	// force client to popup CA menu.
+#ifndef WSW_RELEASE
 	if( game.gametype == GAMETYPE_CA && g_ca_classmode->integer && !g_instagib->integer && team != TEAM_SPECTATOR )
+#else
+	if( game.gametype == GAMETYPE_CA && !g_instagib->integer && team != TEAM_SPECTATOR )
+#endif
 		trap_GameCmd( ent, "mnca" );
 
 	return qtrue;
