@@ -108,8 +108,10 @@ static void G_Gametype_CA_SetBotClass( edict_t *ent )
 		return;
 	if( game.gametype != GAMETYPE_CA )
 		return;
+#ifndef WSW_RELEASE
 	if( !g_ca_classmode->integer )
 		return;
+#endif
 	if( g_instagib->integer )
 		return;
 
@@ -141,6 +143,10 @@ qboolean G_Gametype_CA_ClientRespawn( edict_t *self )
 
 	self->r.svflags &= ~SVF_NOCLIENT;
 
+	//if invalid be spectator
+	if( self->s.team < 0 || self->s.team >= GS_MAX_TEAMS )
+		self->s.team = TEAM_SPECTATOR;
+
 	GClip_UnlinkEntity( self );
 
 	index = self-game.edicts-1;
@@ -299,15 +305,19 @@ qboolean G_Gametype_CA_ClientRespawn( edict_t *self )
 			ca_weaponflag_t	weaponflag;
 			int gb, rg, gl, rl, pg, lg, eb;
 
+#ifndef WSW_RELEASE
 			if( g_ca_classmode->integer ) {
+#endif
 				ca_playerclass_t	playerclass = cagame.playerclass[PLAYERNUM(self)];
 				char			weaponname[MAX_TOKEN_CHARS];
 				weaponflag = G_Gametype_CA_WeaponFlag( qtrue, playerclass );
 				G_Gametype_CA_WeaponName( weaponflag, weaponname, sizeof(weaponname) );
 				// G_PrintMsg( self, "Your class is %s (%s)\n", G_Gametype_CA_ClassName( playerclass ), weaponname );
+#ifndef WSW_RELEASE
 			} else {
 				weaponflag = G_Gametype_CA_WeaponFlag( qfalse, CA_PLAYERCLASS_GRUNT ); // GRUNT is dummy
 			}
+#endif
 
 			gb = rg = gl = rl = pg = lg = eb = 0;
 			G_Gametype_CA_SetAmmo( g_ca_weak_ammo->string, &gb, &rg, &gl, &rl, &pg, &lg, &eb );
@@ -481,7 +491,11 @@ char *G_Gametype_CA_ScoreboardMessage( edict_t *ent, edict_t *killer )
 				PLAYERNUM(e),
 				match.scores[PLAYERNUM(e)].score,
 				(int)(e->r.client->resp.total_damage_given * damage_scale),
+#ifndef WSW_RELEASE
 				(g_ca_classmode->integer && !g_ca_competitionmode->integer && !g_instagib->integer) ? (cagame.playerclass[PLAYERNUM(e)] + 1) : 0,
+#else
+				(!g_ca_competitionmode->integer && !g_instagib->integer) ? (cagame.playerclass[PLAYERNUM(e)] + 1) : 0,
+#endif
 				e->r.client->r.ping > 999 ? 999 : e->r.client->r.ping,
 				G_IsDead(e),		// wsw : imp : Added this to parse
 				match.ready[PLAYERNUM(e)],
@@ -722,6 +736,7 @@ void G_Gametype_CA_CheckRules( void )
 			match.roundstate = MATCH_STATE_POSTMATCH;
 			match.roundstarttime = level.time;
 			match.roundendtime = level.time + fabs(G_POSTMATCH_TIMELIMIT);
+			G_Match_RemoveAllClientLasers();
 			// G_Match_RemoveAllProjectiles(); // remove all fires
 
 			if( is_match_end ) {
@@ -762,6 +777,7 @@ void G_Gametype_CA_CheckRules( void )
 			match.roundstate = MATCH_STATE_PLAYTIME;
 			match.roundstarttime = level.time;
 			match.roundendtime = match.endtime;
+			G_Match_RemoveAllClientLasers();
 			G_Match_RemoveAllProjectiles();
 			G_AnnouncerSound( NULL, trap_SoundIndex(va(S_ANNOUNCER_COUNTDOWN_FIGHT_1_to_2, (rand()&1)+1)), GS_MAX_TEAMS, qtrue );
 			G_CenterPrintMsg( NULL, "FIGHT!\n" );
@@ -842,10 +858,12 @@ void G_Gametype_CA_PlayerClass_Cmd( edict_t *ent )
 		return;
 	}
 
+#ifndef WSW_RELEASE
 	if( !g_ca_classmode->integer ) {
 		G_PrintMsg( ent, "This feature is only available if g_ca_classmode is 1.\n" );
 		return;
 	}
+#endif
 
 	if( g_instagib->integer ) {
 		G_PrintMsg( ent, "This feature is not available in instagib mode.\n" );
