@@ -59,6 +59,7 @@ void G_Gametype_GENERIC_SetUpCountdown( void )
 {
 	edict_t *ent;
 
+	G_Match_RemoveAllClientLasers();
 	G_Match_RemoveAllProjectiles();
 	G_Match_RespawnAllItems();
 
@@ -82,6 +83,8 @@ void G_Gametype_GENERIC_SetUpCountdown( void )
 	{
 		if( !ent->r.inuse || ent->s.team == TEAM_SPECTATOR )
 			continue;
+		if( ent->s.weapon == WEAP_LASERGUN )
+			G_HideClientLaser( ent );
 
 		InitClientResp( ent->r.client );
 	}
@@ -1231,6 +1234,23 @@ void G_Match_SetUpDelayedItems( void )
 	}
 }
 
+//=================
+//G_Match_RemoveAllClientLasers
+// Vic: FIXME, this is incredibly stupid
+//=================
+void G_Match_RemoveAllClientLasers( void )
+{
+	edict_t *ent;
+
+	for( ent = game.edicts + game.maxclients; ENTNUM(ent) < game.numentities; ent++ ) 
+	{
+		if( ent->s.weapon == WEAP_LASERGUN )
+		{
+			G_HideClientLaser( ent );
+		}
+	}
+}
+
 //=================
 //G_Match_RemoveAllProjectiles
 //=================
@@ -1337,6 +1357,9 @@ void G_Match_RespawnAllClients( void )
 		if( ent->r.client->is_coach ) // ignore coachs
 			continue; 
 
+		if( ent->s.weapon == WEAP_LASERGUN )
+			G_HideClientLaser( ent );
+
 		//reset respawn count
 		ent->r.client->resp.respawnCount = 0;
 
