@@ -146,10 +146,15 @@ void W_Prestep( edict_t *ent, edict_t *ignore )
 	trace_t	tr;
 	vec3_t	dest;
 	vec3_t dir;
+	int		mask;
 	VectorNormalize2( ent->velocity, dir );
 	VectorMA( ent->s.origin, g_projectile_prestep->value, dir, dest );
 
-	G_Trace4D( &tr, ent->s.origin, ent->r.mins, ent->r.maxs, dest, ignore, MASK_SHOT, ent->timeDelta );
+	mask = MASK_SHOT;
+	if( game.gametype == GAMETYPE_RACE )
+		mask = MASK_SOLID;
+
+	G_Trace4D( &tr, ent->s.origin, ent->r.mins, ent->r.maxs, dest, ignore, mask, ent->timeDelta );
 
 	VectorCopy( tr.endpos, ent->s.origin );
 	VectorCopy( tr.endpos, ent->s.old_origin );
@@ -193,7 +198,7 @@ static edict_t *W_Fire_Projectile( edict_t *self, vec3_t start, vec3_t dir, int
 	projectile->movetype = MOVETYPE_FLYMISSILE;
 
 	// wsw: make missile fly through players in race
-	if(game.gametype==GAMETYPE_RACE)
+	if( game.gametype == GAMETYPE_RACE )
 		projectile->r.clipmask = MASK_SOLID;
 	else
 		projectile->r.clipmask = MASK_SHOT;
@@ -263,10 +268,14 @@ void W_Fire_Blade( edict_t *self, int range, vec3_t start, vec3_t aimdir, int da
 	edict_t *event, *other = NULL;
 	vec3_t	end;
 	trace_t	trace;
+	int		mask = MASK_SHOT;
 
 	VectorMA( start, range, aimdir, end );
 
-	G_Trace4D( &trace, start, NULL, NULL, end, self, MASK_SHOT, timeDelta );
+	if( game.gametype == GAMETYPE_RACE )
+		mask = MASK_SOLID;
+
+	G_Trace4D( &trace, start, NULL, NULL, end, self, mask, timeDelta );
 	if( trace.ent == -1 ) //didn't touch anything
 		return;
 
@@ -427,7 +436,6 @@ edict_t *W_Fire_Shockwave( edict_t *self, vec3_t start, vec3_t aimdir, float spe
 
 	wave->timeout = level.time + timeout;
 	wave->accel = -750.0;
-	wave->r.clipmask = MASK_SOLID;
 	wave->nextthink = level.time + 1;
 	wave->think = W_Think_Shockwave;
 
@@ -750,6 +758,9 @@ static void W_Plasma_Backtrace( edict_t *ent, const vec3_t start )
 	trace_t	tr;
 	vec3_t	mins, maxs, oldorigin;
 
+	if( game.gametype == GAMETYPE_RACE )
+		return;
+
 	if( ent->style == MOD_PLASMA_S ) {
 		VectorSet( mins, -10.0f, -10.0f, -10.0f );
 		VectorSet( maxs, 10.0f, 10.0f, 10.0f );
@@ -910,6 +921,8 @@ void W_Fire_Electrobolt_Strong( edict_t *self, vec3_t start, vec3_t aimdir, floa
 	VectorCopy( start, from );
 	ignore = self;
 	mask = MASK_SHOT;
+	if( game.gametype == GAMETYPE_RACE )
+		mask = MASK_SOLID;
 	tr.ent = -1;
 	while( ignore )
 	{
@@ -1035,6 +1048,24 @@ void G_HideClientLaser( edict_t *ent )
 	}
 }
 
+//==================
+//G_Laser_Think
+//==================
+static void G_Laser_Think( edict_t *ent )
+{
+	edict_t *owner = &game.edicts[ent->s.ownerNum];
+
+	assert( ent->s.ownerNum && ent->s.modelindex );
+
+	if( !owner->r.inuse || owner->r.svflags & SVF_NOCLIENT || owner->s.team == TEAM_SPECTATOR || owner->deadflag )
+	{
+		G_HideLaser( ent );
+		return;
+	}
+
+	ent->nextthink = level.time + 100;
+}
+
 //==================
 //W_Fire_Lasergun
 //==================
@@ -1052,7 +1083,6 @@ void W_Fire_Lasergun( edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 	for( i = game.maxclients; i < game.maxentities; i++ )
 	{
 		e = &game.edicts[i];
-		
 		if( !e->r.inuse )
 			continue;
 
@@ -1089,6 +1119,8 @@ void W_Fire_Lasergun( edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 	VectorCopy( start, from );
 	ignore = self;
 	mask = MASK_SHOT;
+	if( game.gametype == GAMETYPE_RACE )
+		mask = MASK_SOLID;
 	while( ignore )
 	{
 		G_Trace4D( &tr, from, NULL, NULL, end, ignore, mask, timeDelta );
@@ -1117,9 +1149,8 @@ void W_Fire_Lasergun( edict_t *self, vec3_t start, vec3_t aimdir, int damage, in
 	VectorCopy( from, laser->s.origin );
 	VectorCopy( start, laser->s.origin2 ); // used in the case the owner isn't in the PVS
 	laser->s.range = range;
-
-	laser->think = NULL;
-	laser->nextthink = 0;
+	laser->think = G_Laser_Think;
+	laser->nextthink = level.time + 100;
 
 	if ( missed )
 		G_AwardPlayerMissedLasergun( self, mod );
@@ -1141,7 +1172,6 @@ void W_Fire_Lasergun_Weak( edict_t *self, vec3_t start, vec3_t end, vec3_t aimdi
 	for( i = game.maxclients; i < game.maxentities; i++ )
 	{
 		e = &game.edicts[i];
-
 		if( !e->r.inuse )
 			continue;
 
@@ -1204,6 +1234,8 @@ void W_Fire_Lasergun_Weak( edict_t *self, vec3_t start, vec3_t end, vec3_t aimdi
 				VectorCopy( segmentStart, from );
 				ignore = segmentIgnore;
 				mask = MASK_SHOT;
+				if( game.gametype == GAMETYPE_RACE )
+					mask = MASK_SOLID;
 				while( ignore )
 				{
 					G_Trace4D( &trace, from, NULL, NULL, segmentEnd, ignore, mask, timeDelta );
@@ -1257,9 +1289,8 @@ beamfinished:
 	VectorCopy( self->s.angles, laser->s.angles ); // (need player angles for curved) used in the case the owner isn't in the PVS
 	laser->s.range = range;
 	//laser->s.skinnum = (int)VectorLengthFast( from );
-
-	laser->think = NULL;
-	laser->nextthink = 0;
+	laser->think = G_Laser_Think;
+	laser->nextthink = level.time + 100;
 
 	if( missed )
 		G_AwardPlayerMissedLasergun( self, mod );
