@@ -442,7 +442,7 @@ void player_die( edict_t *ent, edict_t *inflictor, edict_t *attacker, int damage
 	int		contents;
 	edict_t	*body;
 
-	if( attacker && attacker->r.client )
+	if( attacker && attacker->r.client && attacker != ent )
 		G_UpdateFollow( FOLLOW_KILLER, attacker );
 
 	VectorClear( ent->avelocity );
@@ -558,6 +558,10 @@ qboolean ClientRespawn( edict_t *self )
 
 	self->r.svflags &= ~SVF_NOCLIENT;
 
+	//if invalid be spectator
+	if( self->s.team < 0 || self->s.team >= GS_MAX_TEAMS )
+		self->s.team = TEAM_SPECTATOR;
+
 	GClip_UnlinkEntity( self );
 
 	index = self-game.edicts-1;
@@ -574,7 +578,8 @@ qboolean ClientRespawn( edict_t *self )
 	client->pers = pers;
 
 	self->deadflag = DEAD_NO;
-	ClientUserinfoChanged( self, userinfo );
+	ClientUserinfoChanged( self, userinfo ); // it also sets modelindexes and skinnum
+	self->s.modelindex2 = 0;
 
 	// clear entity values
 	memset( &self->snap, 0, sizeof(self->snap) );
@@ -624,9 +629,6 @@ qboolean ClientRespawn( edict_t *self )
 	self->s.effects = 0;
 	self->s.light = 0;
 
-	// modelindex and skinnum are set at calling to update userinfo
-	self->s.modelindex2 = 0;
-
 	//splitmodels: clean up animations
 	self->pmAnim.anim_priority[LOWER] = ANIM_BASIC;
 	self->pmAnim.anim_priority[UPPER] = ANIM_BASIC;
@@ -657,17 +659,12 @@ qboolean ClientRespawn( edict_t *self )
 	for( i = 0; i < 3; i++ )
 		client->ps.pmove.delta_angles[i] = ANGLE2SHORT(self->s.angles[i]) - client->pers.cmd_angles[i];
 
-	//if invalid join spectator
-	if( self->s.team < 0 || self->s.team >= GS_MAX_TEAMS )
-		self->s.team = TEAM_SPECTATOR;
-
 	//don't put spectators in the game
 	if( self->s.team == TEAM_SPECTATOR )
 	{
 		self->movetype = MOVETYPE_NOCLIP;
 		self->r.solid = SOLID_NOT;
 		self->r.svflags |= SVF_NOCLIENT;
-		self->s.modelindex = 0;
 	}
 	else
 	{
@@ -1448,10 +1445,12 @@ void ClientThink( edict_t *ent, usercmd_t *ucmd, int timeDelta )
 	pm.cmd = *ucmd;
 	pm.max_walljumps = GS_GameType_MaxWallJumps( game.gametype );
 	pm.passent = ENTNUM(ent);
-	if( G_IsDead(ent) || game.gametype == GAMETYPE_RACE )
+	pm.contentmask = MASK_PLAYERSOLID;
+	// modify the mask under special conditions
+	if( G_IsDead(ent) )
 		pm.contentmask = MASK_DEADSOLID;
-	else
-		pm.contentmask = MASK_PLAYERSOLID;
+	if( game.gametype == GAMETYPE_RACE )
+		pm.contentmask = MASK_SOLID;
 	if( ent->movetype == MOVETYPE_NOCLIP )
 		pm.contentmask = 0;
 
