@@ -1131,22 +1131,8 @@ static void Weapon_GenericFrametime( edict_t *ent, int msec, int timeDelta, fire
 
 	// hide laser if we are not shooting it anymore
 	if( ent->s.weapon == WEAP_LASERGUN && !(actions & WEAPON_ACTION_STATE_CHANGE) &&
-		client->weaponstate.status != WEAPON_RELOADING )
-	{
-		edict_t	*e;
-		int		i;
-
-		for( i = game.maxclients; i < game.maxentities; i++ ) {
-			e = &game.edicts[i];
-			if( !e->r.inuse )
-				continue;
-
-			if( e->s.ownerNum == ENTNUM(ent) && (e->s.type == ET_CURVELASERBEAM || e->s.type == ET_LASERBEAM) &&
-				e->s.modelindex ) {
-				G_HideLaser( e );
-				break;
-			}
-		}
+		client->weaponstate.status != WEAPON_RELOADING ) {
+		G_HideClientLaser( ent );
 	}
 
 	//weapdown animation
