@@ -861,28 +861,24 @@ void Matrix_EulerAngles( const vec3_t m[3], vec3_t angles )
 	vec_t	pitch, yaw, roll;
 
 	pitch = -asin( m[0][2] );
-	c = cos ( pitch );
-	pitch = RAD2DEG( pitch );
-
-	if ( fabs( c ) > 0.005 )             // Gimball lock?
-	{
+	c = cos( pitch );
+	if ( fabs( c ) > 5*10e-6 )			// Gimball lock?
+	{	// no
 		c = 1.0f / c;
+		pitch = RAD2DEG( pitch );
 		yaw = RAD2DEG( atan2 ( m[0][1] * c, m[0][0] * c ) );
 		roll = RAD2DEG( atan2 ( -m[1][2] * c, m[2][2] * c ) );
 	}
 	else
-	{
-		if (m[0][2] > 0)
-			pitch = -90;
-		else
-			pitch = 90;
+	{	// yes
+		pitch = m[0][2] > 0 ? -90 : 90;
 		yaw = RAD2DEG( atan2 ( m[1][0], -m[1][1] ) );
-		roll = 0;
+		roll = 180;
 	}
 
-	angles[PITCH] = anglemod( pitch );
-	angles[YAW] = anglemod( yaw );
-	angles[ROLL] = anglemod( roll );
+	angles[PITCH] = pitch;
+	angles[YAW] = yaw;
+	angles[ROLL] = roll;
 }
 
 void Matrix_Rotate( vec3_t m[3], vec_t angle, vec_t x, vec_t y, vec_t z )
