@@ -170,6 +170,9 @@ typedef UINT_PTR quintptr;
 #    define ARCH "x86_64"
 #    define CPUSTRING "x86_64"
 #  endif
+# elif defined(__powerpc__)
+#  define CPUSTRING "ppc"
+#  define ARCH "ppc"
 # elif defined(__alpha__)
 #  define CPUSTRING "axp"
 #  define ARCH "axp"
@@ -191,56 +194,39 @@ typedef uintptr_t quintptr;
 
 //==============================================
 
-#if defined (__APPLE__) || defined (MACOSX)
+#if defined(__APPLE__) && defined(__MACH__)
+
+#ifndef __MACOSX__
+#define __MACOSX__
+#endif
 
 # define HAVE_INLINE
 
+#ifndef HAVE_STRCASECMP // SDL_config.h seems to define this too...
 # define HAVE_STRCASECMP
+#endif
+
+# define LIB_DIRECTORY "libs"
+# define LIB_SUFFIX ".dylib"
 
 //# define GL_FORCEFINISH
-# define GL_DRIVERNAME	"libGL.dylib"
+# define GL_DRIVERNAME	"/System/Library/Frameworks/OpenGL.framework/Libraries/libGL.dylib"
 
 # define VORBISFILE_LIBNAME	"libvorbisfile.dylib"
 
+//Mac OSX has universal binaries, no need for cpu dependency
 # define BUILDSTRING "MacOSX"
-
-# ifdef __i386__
-#  define CPUSTRING "i386"
-# elif defined(__ppc__)
-#  define CPUSTRING "ppc"
-# else
-#  define CPUSTRING "Unknown"
-# endif
-
-#if defined __FreeBSD__
-# if defined __i386__
-#  define ARCH "freebsd_i386"
-#  define CPUSTRING "i386"
-# elif defined __x86_64__
-#  define ARCH "freebsd_x86_64"
-#  define CPUSTRING "x86_64"
-# endif
-#elif defined __i386__
-# define ARCH "i386"
-# define CPUSTRING "i386"
-#elif defined __x86_64__
-# define ARCH "x86_64"
-# define CPUSTRING "x86_64"
-#elif defined __alpha__
-# define ARCH "axp"
-# define CPUSTRING "axp"
-#elif defined __powerpc__
-# define ARCH "ppc"
-# define CPUSTRING "ppc"
-#elif defined __sparc__
-# define ARCH "sparc"
-# define CPUSTRING "sparc"
-#else
-# error "Unknown ARCH"
-#endif
+# define CPUSTRING "universal"
+# define ARCH "mac"
 
 # define VAR(x)	#x
 
+# include <stdint.h>
+typedef int64_t qint64;
+typedef uint64_t quint64;
+typedef intptr_t qintptr;
+typedef uintptr_t quintptr;
+
 #endif
 
 //==============================================
