@@ -985,7 +985,7 @@ cmodel_t *CM_LoadMap( cmodel_state_t *cms, char *name, qboolean clientload, unsi
 	if( !buf )
 		Com_Error( ERR_DROP, "Couldn't load %s", name );
 
-	cms->checksum = LittleLong( Com_BlockChecksum( buf, length ) );
+	cms->checksum = Com_BlockChecksum( buf, length );
 	*checksum = cms->checksum;
 
 	header = *(dheader_t *)buf;
