@@ -1023,7 +1023,7 @@ void Qcommon_Frame( unsigned int realmsec )
 	static quint64	fc = 0;
 	char	*s;
 	int		time_before = 0, time_between = 0, time_after = 0;
-	int		gamemsec;
+	static unsigned int		gamemsec;
 
 	if( setjmp (abortframe) )
 		return;			// an ERR_DROP was thrown
