@@ -47,9 +47,7 @@ static const char *forbidden_gamedirs[] = {
 	"docs",
 	"libs",
 	"browser",
-#ifdef BATTLEYE
-	"BattlEye",
-#endif
+	"Warsow.app",
 	NULL
 };
 
