@@ -341,7 +341,8 @@ mempool_t *_Mem_AllocTempPool( const char *name, const char *filename, int filel
 
 void _Mem_FreePool( mempool_t **pool, int musthave, int canthave, const char *filename, int fileline )
 {
-	mempool_t **chainAddress, **next;
+	mempool_t *tmp, *next;
+	mempool_t **chainAddress;
 #ifdef SHOW_NONFREED
 	memheader_t *mem;
 #endif
@@ -357,9 +358,10 @@ void _Mem_FreePool( mempool_t **pool, int musthave, int canthave, const char *fi
 	// note that children will be freed no matter if their flags 
 	// do not match musthave\canthave pair
 	if( (*pool)->child ) {
-		for( chainAddress = &(*pool)->child; *chainAddress; chainAddress = next ) {
-			next = &((*chainAddress)->next);
-			_Mem_FreePool( chainAddress, 0, 0, filename, fileline );
+		for( chainAddress = &(*pool)->child; *chainAddress; chainAddress = &next ) {
+			tmp = *chainAddress;
+			next = tmp->next;
+			_Mem_FreePool( &tmp, 0, 0, filename, fileline );
 		}
 	}
 	
