@@ -20,9 +20,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "qcommon.h"
 
-#if defined(__APPLE__) || defined (MACOSX)
+#if defined(__MACOSX__)
 #include <arpa/inet.h>
-#endif /* __APPLE__ || MACOSX */
+#endif /* __MACOSX__ */
 
 /*
 
