@@ -30,7 +30,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //#define	PARANOID			// speed sapping error checking
 
 #ifndef VERSION
-# define VERSION			0.31
+# define VERSION			0.32
 #endif
 
 #ifndef APPLICATION
@@ -208,9 +208,6 @@ enum svc_ops_e
 	svc_clcack,
 	svc_servercs, //tmp jalfixme : send reliable commands as unreliable
 	svc_frame
-#ifdef BATTLEYE
-	, svc_battleye
-#endif
 };
 
 //==============================================
@@ -225,9 +222,6 @@ enum clc_ops_e
 	clc_move,				// [[usercmd_t]
 	clc_svcack,
 	clc_clientcommand			// [string] message
-#ifdef BATTLEYE
-	, clc_battleye
-#endif
 };
 
 //==============================================
@@ -235,7 +229,6 @@ enum clc_ops_e
 // serverdata flags
 #define SV_BITFLAGS_PURE				(1<<0)
 #define SV_BITFLAGS_RELIABLE			(1<<1)
-#define SV_BITFLAGS_BATTLEYE			(1<<7)
 
 // framesnap flags
 #define FRAMESNAP_FLAG_DELTA			(1<<0)
@@ -500,9 +493,6 @@ NET
 #define	MAX_PACKETLEN			1400		// max size of a network packet
 #define	MAX_MSGLEN				32768		// max length of a message, which may be fragmented into multiple packets
 // wsw: Medar: doubled the MSGLEN as a temporary solution for multiview on bigger servers
-#ifdef BATTLEYE
-#define MAX_BE_MSGLEN			2048
-#endif
 #define	FRAGMENT_SIZE			(MAX_PACKETLEN - 96)
 #define	FRAGMENT_LAST			(1<<14)
 #define	FRAGMENT_BIT			(1<<31)
