@@ -22,6 +22,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef __WEBDOWNLOAD__H__
 #define __WEBDOWNLOAD__H__
 
-int Web_Get(const char *url,const char *referer,const char *name,int resume, int timeout, int (*_progress)(double));
+int Web_Get(const char *url,const char *referer,const char *name,int resume, int connect_timeout, int timeout, int (*_progress)(double));
 
 #endif
