@@ -396,7 +396,7 @@ void Mod_LoadAliasMD3Model( model_t *mod, model_t *parent, void *buffer )
 	for( i = 0; i < poutmodel->nummeshes; i++, poutmesh++ ) {
 		if( strncmp( (const char *)pinmesh->id, IDMD3HEADER, 4) )
 			Com_Error( ERR_DROP, "mesh %s in model %s has wrong id (%s should be %s)",
-					 pinmesh->name, mod->name, LittleLong( pinmesh->id ), IDMD3HEADER );
+					 pinmesh->name, mod->name, LittleLong( (int)pinmesh->id ), IDMD3HEADER );
 
 		Q_strncpyz( poutmesh->name, pinmesh->name, MD3_MAX_PATH );
 
@@ -662,7 +662,12 @@ void R_DrawAliasFrameLerp( const meshbuffer_t *mb, model_t *mod, float backlerp,
 	shader_t		*shader;
 	static	maliasmesh_t *alias_prevmesh;
 	static	shader_t *alias_prevshader;
-	static	int		alias_framecount;
+	static	int		alias_framecount, alias_riparams;
+
+	if( alias_riparams != ri.params ) {
+		alias_riparams = ri.params;			// do not try to lock arrays between RI updates
+		alias_framecount = !r_framecount;
+	}
 
 	if( !shadow && (e->flags & RF_VIEWERMODEL) && !(ri.params & (RP_MIRRORVIEW|RP_PORTALVIEW|RP_SKYPORTALVIEW)) )
 		return;
@@ -790,6 +795,8 @@ void R_DrawAliasFrameLerp( const meshbuffer_t *mb, model_t *mod, float backlerp,
 			R_DrawShadowVolumes( &alias_mesh, e->lightingOrigin, alias_mins, alias_maxs, alias_radius );
 #endif
 		}
+
+		R_ClearArrays ();
 	}
 }
 
@@ -837,7 +844,7 @@ void R_AddAliasModelToList( entity_t *e )
 	maliasmesh_t	*mesh;
 
 	mod = R_AliasLODForDistance( e );
-	if ( !(aliasmodel = mod->aliasmodel) )
+	if ( !(aliasmodel = mod->aliasmodel) || !aliasmodel->nummeshes )
 		return;
 
 	R_AliasModelBBox( e, mod );
