@@ -2131,7 +2131,7 @@ void R_RenderMeshBuffer( const meshbuffer_t *mb, qboolean shadowpass )
 	if( r_currentShader->flags & SHADER_FLARE )
 		dlightBits = 0;
 	else
-		dlightBits = mb->dlightbits;
+		dlightBits = surf ? mb->dlightbits : 0;
 
 	R_LockArrays( numVerts );
 	pass = r_currentShader->passes;
