@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "r_local.h"
-#if defined (__APPLE__) || defined (MACOSX)
+#if defined (__MACOSX__)
 #include <jpeglib.h>
 #else
 #include "jpeglib.h"
