@@ -18,6 +18,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#include "../qcommon/qcommon.h"
+
 #ifdef __cplusplus
 # define QGL_EXTERN extern "C"
 #else
@@ -40,15 +42,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # define QGL_GLX_EXT(type,name,params) QGL_EXTERN type (APIENTRY * q##name) params;
 #endif
 
-#if defined (__APPLE__) || defined (MACOSX)
+#if defined (__MACOSX__)
 # define QGL_WGL(type,name,params)
 # define QGL_WGL_EXT(type,name,params)
 # define QGL_GLX(type,name,params)
 # define QGL_GLX_EXT(type,name,params)
 #endif
 
-#include "../qcommon/qcommon.h"
-
 #define QGL_FUNC(type,name,params) QGL_EXTERN type (APIENTRY * q##name) params;
 #define QGL_EXT(type,name,params) QGL_EXTERN type (APIENTRY * q##name) params;
 
