@@ -1389,7 +1389,7 @@ static float R_FarClip( void )
 	}
 
 	farclip_dist = sqrt( farclip_dist );
-	return max( max( r_farclip_min, farclip_dist ) + r_farclip_bias, ri.farClip );
+	return max( r_farclip_min, farclip_dist ) + r_farclip_bias;
 }
 
 /*
@@ -1474,12 +1474,6 @@ void R_SetupFrame (void)
 	VectorCopy( ri.refdef.vieworg, ri.viewOrigin );
 	AngleVectors( ri.refdef.viewangles, ri.vpn, ri.vright, ri.vup );
 
-	R_SetupProjectionMatrix( &ri.refdef, ri.projectionMatrix );
-	if( ri.params & RP_MIRRORVIEW )
-		ri.projectionMatrix[0] = -ri.projectionMatrix[0];
-
-	R_SetupModelviewMatrix( &ri.refdef, ri.worldviewMatrix );
-
 	ri.lod_dist_scale_for_fov = tan( ri.refdef.fov_x * (M_PI/180) * 0.5f );
 
 	// current viewcluster
@@ -1494,6 +1488,19 @@ void R_SetupFrame (void)
 	}
 }
 
+/*
+===============
+R_SetupViewMatrices
+===============
+*/
+void R_SetupViewMatrices (void)
+{
+	R_SetupProjectionMatrix( &ri.refdef, ri.projectionMatrix );
+	if( ri.params & RP_MIRRORVIEW )
+		ri.projectionMatrix[0] = -ri.projectionMatrix[0];
+	R_SetupModelviewMatrix( &ri.refdef, ri.worldviewMatrix );
+}
+
 /*
 =============
 R_Clear
@@ -1658,6 +1665,8 @@ void R_RenderView( refdef_t *fd )
 
 	R_DrawWorld ();
 
+	R_SetupViewMatrices ();			// we know the the farclip by now
+
 	R_DrawCoronas ();
 
 	if( r_speeds->integer )
