@@ -731,7 +731,8 @@ void R_DrawPortalSurface( const meshbuffer_t *mb )
 	ri.clipPlane = plane;
 	Vector4Set( ri.scissor, ri.refdef.x + x, ri.refdef.y + y, w, h );
 	VectorCopy( origin, ri.refdef.vieworg );
-	VectorCopy( angles, ri.refdef.viewangles );
+	for( i = 0; i < 3; i++ )
+		ri.refdef.viewangles[i] = anglemod( angles[i] );
 
 	R_RenderView( &ri.refdef );
 
