@@ -194,6 +194,8 @@ void Mod_LoadSkeletalModel( model_t *mod, model_t *parent, void *buffer )
 			Com_Error( ERR_DROP, "Could not find pose file for %s", mod->name );
 
 		Mod_LoadSkeletalPose( poseName, mod, buf );
+
+		FS_FreeFile( buf );
 	}
 
 	// clear model's bounding box
@@ -845,6 +847,8 @@ buildtangent:
 			R_DrawShadowVolumes( &skm_mesh, e->lightingOrigin, skm_mins, skm_maxs, skm_radius );
 #endif
 		}
+
+		R_ClearArrays ();
 	}
 }
 
@@ -892,7 +896,7 @@ void R_AddSkeletalModelToList( entity_t *e )
 	mskmodel_t		*skmodel;
 
 	mod = R_SkeletalModelLODForDistance ( e );
-	if( !(skmodel = mod->skmodel) )
+	if( !(skmodel = mod->skmodel) || !skmodel->nummeshes )
 		return;
 
 	R_SkeletalModelBBox ( e, mod );
