@@ -122,10 +122,6 @@ qboolean SV_ClientConnect( const socket_t *socket, const netadr_t *address, clie
 	Q_strncpyz( client->userinfo, userinfo, sizeof(client->userinfo) );
 	SV_UserinfoChanged( client );
 
-#ifdef BATTLEYE
-	MSG_Init( &client->be.outMsg, client->be.outMsgBuf, sizeof(client->be.outMsgBuf) );
-#endif
-
 	return qtrue;
 }
 
@@ -177,14 +173,6 @@ void SV_DropClient( client_t *drop, int type, const char *format, ... )
 			Com_Printf( "Connecting client %s%s disconnected (%s%s)\n", drop->name, S_COLOR_WHITE, reason,
 				S_COLOR_WHITE );
 		}
-
-#ifdef BATTLEYE
-		if( svbe.module && drop->state == CS_SPAWNED )
-		{
-			svbe.RemovePlayer( drop - svs.clients );
-			MSG_Clear( &drop->be.outMsg );
-		}
-#endif
 	}
 
 	if( drop->download.name )
@@ -272,10 +260,6 @@ static void SV_New_f( client_t *client )
 			sv_bitflags |= SV_BITFLAGS_PURE;
 		if( client->reliable )
 			sv_bitflags |= SV_BITFLAGS_RELIABLE;
-#ifdef BATTLEYE
-		if( svbe.module )
-			sv_bitflags |= SV_BITFLAGS_BATTLEYE;
-#endif
 		MSG_WriteByte( &tmpMessage, sv_bitflags );
 	}
 
@@ -457,11 +441,6 @@ static void SV_Begin_f( client_t *client )
 #ifndef DISABLE_DEFER
 	Cbuf_InsertFromDefer();
 #endif
-
-#ifdef BATTLEYE
-	if( svbe.module && !(client->edict && (client->edict->r.svflags & SVF_FAKECLIENT)) )
-		svbe.AddPlayer( client - svs.clients, client->name, NULL );
-#endif
 }
 
 //=============================================================================
@@ -839,6 +818,8 @@ ucmd_t ucmds[] =
 	{ "demolist", SV_DemoList_f },
 	{ "svdemoget", SV_DemoGet_f },
 
+    { "svmotd", SV_MOTD_Get_f },
+
 	{ NULL, NULL }
 };
 
@@ -875,25 +856,6 @@ static void SV_ExecuteUserCommand( client_t *client, char *s )
 }
 
 
-#ifdef BATTLEYE
-static qboolean SV_ParseCLCBattleye( client_t *client, msg_t *msg )
-{
-	size_t len;
-	qbyte packet[MAX_BE_MSGLEN - sizeof(short) - 1];
-
-	len = MSG_ReadShort( msg );
-	if( len <= 0 || len > sizeof(packet) ) {
-		SV_DropClient( client, DROP_TYPE_GENERAL, "Error: Invalid BattlEye packet size" );
-		return qfalse;
-	}
-	MSG_ReadData( msg, packet, len );
-	// pass this packet to BE Server
-	svbe.NewPacket( client - svs.clients, packet, len );
-
-	return qtrue;
-}
-#endif
-
 /*
 ===========================================================================
 
@@ -1126,17 +1088,6 @@ void SV_ParseClientMessage( client_t *client, msg_t *msg )
 					return;	// disconnect command
 			}
 			break;
-
-#ifdef BATTLEYE
-		case clc_battleye:
-			if( !svbe.module ) {
-				SV_DropClient( client, DROP_TYPE_GENERAL, "Error: Invalid command char" );
-				return;
-			}
-			if( !SV_ParseCLCBattleye( client, msg ) )
-				return;
-			break;
-#endif
 		}
 	}
 }
