@@ -442,6 +442,7 @@ static void SV_AddPureBSP( void )
 	int i;
 	const char *shader;
 
+	SV_AddPureFile( sv.configstrings[CS_MODELS+1] );
 	for( i = 0; (shader = CM_ShaderrefName( svs.cms, i )); i++ ) {
 		SV_AddPureShader( shader );
 	}
@@ -454,6 +455,10 @@ PF_PureModel
 */
 static void PF_PureModel( const char *name )
 {
+#ifdef ZEROTHREEAPI
+	const char *extension;
+#endif
+
 	if( sv.state != ss_loading )
 		return;
 
@@ -461,11 +466,19 @@ static void PF_PureModel( const char *name )
 		return;
 
 #ifdef ZEROTHREEAPI
-	if( name[0] == '*' || !Q_stricmp( COM_FileExtension( name ), ".bsp" ) ) {		// inline model
-#else
-	if( name[0] == '*' ) {		// inline model
-		if( !strcmp( name, "*0" ) )
+	extension = COM_FileExtension( name );
 #endif
+
+	if( name[0] == '*'
+#ifdef ZEROTHREEAPI
+		|| ( extension && !Q_stricmp( extension, ".bsp" ) )
+#endif
+	 ) {		// inline model
+		if( !strcmp( name, "*0" )
+#ifdef ZEROTHREEAPI
+			|| ( extension && !Q_stricmp( extension, ".bsp" ) )
+#endif
+		)
 			SV_AddPureBSP ();	// world
 	} else {
 		SV_AddPureFile( name );
