@@ -67,9 +67,9 @@ cvar_t	*sv_skilllevel;
 // wsw : debug netcode
 cvar_t	*sv_debug_serverCmd;
 
-#ifdef BATTLEYE
-cvar_t	*sv_battleye;
-#endif
+cvar_t  *sv_MOTD;
+cvar_t  *sv_MOTDFile;
+cvar_t  *sv_MOTDString;
 
 //============================================================================
 
@@ -485,19 +485,6 @@ void SV_Frame( int realmsec, int gamemsec )
 		ge->ClearSnap();
 		sv.numframesounds = 0;
 	}
-
-#ifdef BATTLEYE
-	// run BattlEye here
-	if( svbe.module )
-	{
-		if( !svbe.Run() )
-		{
-			// reload now
-			SV_BE_Unload();
-			SV_BE_Load();
-		}
-	}
-#endif
 }
 
 //============================================================================
@@ -589,10 +576,6 @@ void SV_Init( void )
 
 	SV_InitOperatorCommands();
 
-#ifdef BATTLEYE
-	svbe.module = NULL;
-#endif
-
 	sv_mempool = Mem_AllocPool( NULL, "Server" );
 
 	Cvar_Get( "dmflags", 0, CVAR_SERVERINFO );
@@ -625,13 +608,6 @@ void SV_Init( void )
 		sv_pure =				Cvar_Get( "sv_pure", "0", CVAR_ARCHIVE | CVAR_LATCH | CVAR_SERVERINFO );
 	sv_pure_forcemodulepk3 =	Cvar_Get( "sv_pure_forcemodulepk3", "", CVAR_LATCH );
 
-#ifdef BATTLEYE
-	if( dedicated->integer )
-		sv_battleye =			Cvar_Get( "sv_battleye", "1", CVAR_SERVERINFO | CVAR_ARCHIVE | CVAR_LATCH );
-	else
-		sv_battleye =			Cvar_Get( "sv_battleye", "0", CVAR_SERVERINFO | CVAR_READONLY );
-#endif
-
 	sv_noreload =				Cvar_Get( "sv_noreload", "0", 0 );
 	
 	if( dedicated->integer )
@@ -661,6 +637,11 @@ void SV_Init( void )
 		sv_masterservers =			Cvar_Get( "masterservers", DEFAULT_MASTER_SERVERS_IPS, 0 );
 	sv_debug_serverCmd =		Cvar_Get( "sv_debug_serverCmd", "0", CVAR_ARCHIVE );
 
+    sv_MOTD = Cvar_Get( "sv_MOTD", "0", CVAR_ARCHIVE );
+    sv_MOTDFile = Cvar_Get( "sv_MOTDFile", "", CVAR_ARCHIVE );
+    sv_MOTDString = Cvar_Get( "sv_MOTDString", "", CVAR_ARCHIVE );
+    SV_MOTD_Update( );
+
 	// this is a message holder for shared use
 	MSG_Init( &tmpMessage, tmpMessageData, sizeof(tmpMessageData) );
 
