@@ -272,16 +272,6 @@ static char *SV_ShortInfoString( void )
 		}
 	}
 
-#ifdef BATTLEYE
-	if( sv_battleye->integer ) {
-		Q_snprintfz( entry, sizeof(entry), "be\\\\1\\\\" );
-		if( MAX_SVCINFOSTRING_LEN - len > strlen(entry) ) {
-			Q_strncatz( string, entry, sizeof(string) );
-			len = strlen(string);
-		}
-	}
-#endif
-
 	// finish it
 	Q_strncatz( string, "EOT", sizeof(string) );
 	return string;
@@ -581,18 +571,6 @@ static void SVC_DirectConnect( const socket_t *socket, const netadr_t *address )
 			SV_DropClient( newcl, DROP_TYPE_GENERAL, "Need room for a real player" );
 	}
 
-#ifdef BATTLEYE
-	if( svbe.module ) {
-		char *s = Info_ValueForKey( userinfo, "cl_battleye" );
-		if( !s || !(atoi(s)) ) {
-			Netchan_OutOfBandPrint( socket, address, "reject\n%i\n%i\nBattlEye is required on this server\n",
-				DROP_TYPE_GENERAL, 0 );
-			Com_DPrintf( "Rejected a non-BattlEye client.\n" );
-			return;
-		}
-	}
-#endif
-
 	// get the game a chance to reject this connection or modify the userinfo
 	if( !SV_ClientConnect(socket, address, newcl, userinfo, game_port, challenge, qfalse) )
 	{
