@@ -56,6 +56,8 @@ playsound_t	s_playsounds[MAX_PLAYSOUNDS];
 playsound_t	s_freeplays;
 playsound_t	s_pendingplays;
 
+cvar_t		*developer;
+
 cvar_t		*s_volume;
 cvar_t		*s_musicvolume;
 cvar_t		*s_testsound;
@@ -179,6 +181,8 @@ S_Init
 */
 qboolean S_Init( void )
 {
+	developer = trap_Cvar_Get( "developer", "0", 0 );
+
 	s_volume = trap_Cvar_Get( "s_volume", "0.8", CVAR_ARCHIVE );
 	s_musicvolume = trap_Cvar_Get( "s_musicvolume", "0.25", CVAR_ARCHIVE );
 	s_khz = trap_Cvar_Get( "s_khz", "44", CVAR_ARCHIVE );
@@ -1148,7 +1152,7 @@ static void byteSwapRawSamples( int samples, int width, int channels, const qbyt
 		samples <<= 1;
 
 	for( i = 0 ; i < samples ; i++ )
-		((short *)data)[i] = LittleShort( ((short *)data)[i] );
+		((short *)data)[i] = BigShort( ((short *)data)[i] );
 }
 
 /*
@@ -1397,4 +1401,5 @@ void Com_Printf( const char *format, ... )
 
 	trap_Print( msg );
 }
+
 #endif
