@@ -117,7 +117,7 @@ static int UISCR_VerticalAlignOffset( int align, int height )
 //UI_DrawStringHigh
 //This string is highlighted by the mouse
 //=============
-static void UI_DrawStringHigh( int x, int y, int align, char *str, int maxwidth, struct mufont_s *font, vec4_t color )
+void UI_DrawStringHigh( int x, int y, int align, char *str, int maxwidth, struct mufont_s *font, vec4_t color )
 {
 	int shadowoffset = 1;
 	if( !font )
@@ -503,9 +503,9 @@ void Slider_DoSlide( menucommon_t *s, int dir )
 		UI_Error( "Invalid slidebar range: 'min < max'" );
 
 	// see if the mouse is touching the step buttons
-	if( uis.cursorX < min ) {
+	if( uis.cursorX < min || dir < 0 ) {
 		s->curvalue--;
-	} else if( uis.cursorX > max ) {
+	} else if( uis.cursorX > max || dir > 0 ) {
 		s->curvalue++;
 	} else {
 		newrange = uis.cursorX - min;
@@ -572,18 +572,19 @@ void Scrollbar_DoSlide( menucommon_t *s, int dir )
 	if( max < min )
 		UI_Error( "Invalid scrollbar range: 'min < max'" );
 
-	if ( dir > 1 || dir < -1 )
-		s->curvalue += dir;
-	else if( uis.cursorY < min ) // see if the mouse is touching the step buttons
-		s->curvalue--;
-	else if( uis.cursorY > max )
-		s->curvalue++;
-	else {
+	if ( dir < 3 && dir > -3 && Menu_ItemAtCursor(s->parent) == s && ( uis.cursorY > min && uis.cursorY < max ))
+	{
 		if ( uis.cursorY < cv_pos )
 			s->curvalue = s->curvalue - s->height + 1; //first line gets moved to the last
 		else if ( uis.cursorY > cv_pos + active_scroll )
 			s->curvalue = s->curvalue + s->height - 1; //last line gets moved to the first
 	}
+	else
+	{
+		if ( uis.cursorY < min && Menu_ItemAtCursor(s->parent) == s && dir == 1 )
+			dir = -1;
+		s->curvalue += dir;
+	}
 
 	if( s->curvalue > s->maxvalue )
 		s->curvalue = s->maxvalue;
@@ -711,7 +712,6 @@ static void SpinControl_Init( menucommon_t *s )
 
 	if ( s->title != 0 ) { //sort spincontrols have graphics which can be clicked on
 		s->maxs[0] += s->pict.width * 2; //*2 to account for the space between the pict and the text
-		s->maxs[1] += s->pict.height;
 	}
 }
 
@@ -964,18 +964,9 @@ void Menu_AdjustCursor( menuframework_s *m, int dir )
 */
 void Menu_Center( menuframework_s *menu )
 {
-	int i, width = 0, height = 0;
+	int i, height = 0;
 
-	// x center
-	for( i = 0; i<menu->nitems; i++ ) {
-		if( menu->items[i]->width > width ) //fixed-width lists are scaled on their own
-			width = menu->items[i]->width;
-	}
-	width += 10;
-	if( width > MENU_DEFAULT_WIDTH / 2 ) //its either too big or already scaled for centering
-		menu->x = uis.vidWidth / 2;
-	else
-		menu->x = ( uis.vidWidth - width ) / 2;
+	menu->x = uis.vidWidth / 2;
 
 	// y center
 	for( i = 0; i<menu->nitems; i++ ) {
@@ -983,7 +974,7 @@ void Menu_Center( menuframework_s *menu )
 			height = menu->items[i]->y;
 	}
 	height += 10;
-	menu->y = ( uis.vidHeight - height) / 2;
+	menu->y = ( uis.vidHeight - height ) / 2;
 }
 
 void Menu_AdjustRectangle( int *mins, int *maxs )
@@ -1137,8 +1128,10 @@ qboolean Menu_SlideItem( menuframework_s *s, int dir, int key )
 		switch( item->type )
 		{
 		case MTYPE_SLIDER:
-			if( key == K_MOUSE1 || key == K_MOUSE2 )
-				dir = 0;
+			if( key == K_MOUSE2 )
+				return qfalse;
+			if( key == K_MOUSE1 )
+				dir = 0; //we move to where the mouse is, not just one step
 			Slider_DoSlide( item, dir );
 			return qtrue;
 		case MTYPE_SPINCONTROL:
