@@ -51,9 +51,6 @@ static menucommon_t *menuitem_passwordfilter;
 static menucommon_t *menuitem_gametypefilter;
 static menucommon_t *menuitem_maxpingfilter;
 static menucommon_t *menuitem_namematchfilter;
-#ifdef BATTLEYE
-static menucommon_t *menuitem_battleyefilter;
-#endif
 
 typedef struct server_s
 {
@@ -70,9 +67,6 @@ typedef struct server_s
 	unsigned int ping;
 	unsigned int ping_retries;
 	qboolean	displayed;
-#ifdef BATTLEYE
-	qboolean	battleye;
-#endif
 	char		address[80];
 
 	struct server_s *pnext;
@@ -195,9 +189,6 @@ static server_t *M_RegisterServerItem( char *adr, char *info )
 	newserv->bots = 0;
 	newserv->ping = 9999;
 	newserv->ping_retries = 0;
-#ifdef BATTLEYE
-	newserv->battleye = qfalse;
-#endif
 
 	// set up the actual new item
 	newserv->pnext = servers;
@@ -366,21 +357,6 @@ void M_AddToServerList( char *adr, char *info )
 				continue;
 			}
 
-#ifdef BATTLEYE
-			// got cmd
-			if( !Q_stricmp(tok, "be") ) {
-				int battleye;
-				tok = UI_GetResponseToken( &pntr );
-				if( !tok || !strlen(tok) || !Q_stricmp(tok, "EOT") )
-					break;
-				battleye = (atoi(tok));
-				if( battleye != newserv->battleye ) {
-					need_refresh = qtrue;
-					newserv->battleye = battleye;
-				}
-				continue;
-			}
-#endif
 			// got cmd
 			if( !Q_stricmp(tok, "ping") ) {
 				int ping;
@@ -512,9 +488,6 @@ static void ResetAllServers( void ) {
 		server->bots = 0;
 		server->ping = 9999;
 		server->ping_retries = 0;
-#ifdef BATTLEYE
-		server->battleye = qfalse;
-#endif
 		server = server->pnext;
 		M_RefreshScrollWindowList();
 	}
@@ -962,13 +935,6 @@ static void M_RefreshScrollWindowList( void )
 			if( menuitem_passwordfilter->curvalue - 1 == ptr->password )
 				add = qfalse;
 		}
-#ifdef BATTLEYE
-		// ignore if it has battleye and we are filtering those
-		if( menuitem_battleyefilter && menuitem_battleyefilter->curvalue ) {
-			if( menuitem_battleyefilter->curvalue - 1 == ptr->battleye )
-				add = qfalse;
-		}
-#endif
 		// ignore if it's of filtered ping
 		if( menuitem_maxpingfilter && (int)trap_Cvar_VariableValue("ui_filter_ping") ) {
 			if( ptr->ping > trap_Cvar_VariableValue("ui_filter_ping") )
@@ -1033,9 +999,6 @@ static void M_Connect_UpdateFiltersSettings( menucommon_t *menuitem ) {
 	if( menuitem_skillfilter )trap_Cvar_SetValue( "ui_filter_skill", menuitem_skillfilter->curvalue );
 	if( menuitem_gametypefilter )trap_Cvar_SetValue( "ui_filter_gametype", menuitem_gametypefilter->curvalue );
 	if( menuitem_maxpingfilter )trap_Cvar_Set( "ui_filter_ping", UI_GetMenuitemFieldBuffer(menuitem_maxpingfilter) );
-#ifdef BATTLEYE
-	if( menuitem_battleyefilter )trap_Cvar_SetValue( "ui_filter_battleye", menuitem_battleyefilter->curvalue );
-#endif
 	if( menuitem_namematchfilter )trap_Cvar_Set( "ui_filter_name", UI_GetMenuitemFieldBuffer(menuitem_namematchfilter) );
 
 	M_RefreshScrollWindowList();
@@ -1220,7 +1183,7 @@ static void M_UpdateSeverButton( menucommon_t *menuitem ) {
 	if( server ) {
 		char gametype[7];
 		Q_snprintfz( gametype, sizeof(gametype), "%s%s", (server->instagib ? "i" : ""), server->gametype );
-		Q_snprintfz( menuitem->title, MAX_STRING_CHARS, "%s%-8.8s%-10.10s%s%-12.12s%s%-14.14s%s%-32.32s%s",
+		Q_snprintfz( menuitem->title, MAX_STRING_CHARS, "%s%-10s%-12s%s%-15s%s%-20s%s%-s%s",
 			S_COLOR_WHITE, va("%i", server->ping),
 			va("%i/%i", server->curuser, server->maxuser),
 			S_COLOR_YELLOW, gametype,
@@ -1231,13 +1194,6 @@ static void M_UpdateSeverButton( menucommon_t *menuitem ) {
 		Q_snprintfz(menuitem->title, MAX_STRING_CHARS, NO_SERVER_STRING);
 }
 
-#ifdef BATTLEYE
-static void ToggleCLBattleyeFunc( menucommon_t *menuitem )
-{
-	trap_Cvar_SetValue( "cl_battleye", (menuitem->curvalue != 0) );
-}
-#endif
-
 //==================
 //JoinServer_MenuInit
 //==================
@@ -1269,9 +1225,8 @@ static void JoinServer_MenuInit( void )
 	trap_Cvar_Get( "ui_filter_skill", "0", CVAR_ARCHIVE );
 	trap_Cvar_Get( "ui_filter_gametype", "0", CVAR_ARCHIVE );
 	trap_Cvar_Get( "ui_filter_ping", "0", CVAR_ARCHIVE );
-#ifdef BATTLEYE
-	trap_Cvar_Get( "ui_filter_battleye", "0", CVAR_ARCHIVE );
-#endif
+	trap_Cvar_Get( "ui_sortmethod", "1", CVAR_ARCHIVE );
+	trap_Cvar_Get( "ui_sortmethod_direction", "0", CVAR_ARCHIVE );
 
 	if( uis.vidWidth < 800 )
 		scrollwindow_width = uis.vidWidth * 0.85;
@@ -1335,12 +1290,6 @@ static void JoinServer_MenuInit( void )
 	UI_SetupField( menuitem_maxpingfilter, trap_Cvar_VariableString("ui_filter_ping"), 4, -1 );
 	yoffset += trap_SCR_strHeight( menuitem_maxpingfilter->font );
 
-#ifdef BATTLEYE
-	menuitem_battleyefilter = UI_InitMenuItem( "m_connect_filterbattleye", "BattlEye", UI_SCALED_WIDTH(-100), yoffset, MTYPE_SPINCONTROL, ALIGN_RIGHT_TOP, uis.fontSystemSmall, M_Connect_UpdateFiltersSettings );
-	Menu_AddItem( &s_joinserver_menu, menuitem_battleyefilter );
-	UI_SetupSpinControl( menuitem_battleyefilter, filter_names, trap_Cvar_VariableValue("ui_filter_battleye") );
-#endif
-
 	menuitem_namematchfilter = UI_InitMenuItem( "m_connect_filternamematch", "matched name", UI_SCALED_WIDTH(120), yoffset, MTYPE_FIELD, ALIGN_RIGHT_TOP, uis.fontSystemSmall, M_Connect_UpdateFiltersSettings );
 	Menu_AddItem( &s_joinserver_menu, menuitem_namematchfilter );
 	UI_SetupField( menuitem_namematchfilter, trap_Cvar_VariableString("ui_filter_name"), 12, -1 );
@@ -1351,13 +1300,6 @@ static void JoinServer_MenuInit( void )
 
 	yoffset += trap_SCR_strHeight( menuitem_skillfilter->font );
 
-#ifdef BATTLEYE
-	menuitem = UI_InitMenuItem( "m_connect_toggle_battleye", "BattlEye Client", UI_SCALED_WIDTH(-100), yoffset, MTYPE_SPINCONTROL, MTYPE_SPINCONTROL, uis.fontSystemSmall, ToggleCLBattleyeFunc );
-	Menu_AddItem( &s_joinserver_menu, menuitem );
-	UI_SetupSpinControl( menuitem, offon_names, trap_Cvar_VariableValue("cl_battleye") );
-	//yoffset += trap_SCR_strHeight( menuitem->font );
-#endif
-
 	menuitem = UI_InitMenuItem( "m_connect_search_type", "search", UI_SCALED_WIDTH(120), yoffset, MTYPE_SPINCONTROL, MTYPE_SPINCONTROL, uis.fontSystemSmall, M_Connect_ChangeSearchType );
 	Menu_AddItem( &s_joinserver_menu, menuitem );
 	UI_SetupSpinControl( menuitem, search_names, trap_Cvar_VariableValue("ui_searchtype") );
@@ -1367,12 +1309,6 @@ static void JoinServer_MenuInit( void )
 
 	// sortbar
 	menuitem = UI_InitMenuItem( "m_connect_sortbar_ping", NULL, -xoffset, yoffset, MTYPE_SPINCONTROL, ALIGN_LEFT_TOP, uis.fontSystemSmall, M_Connect_UpdateSortbar );
-	//Save a temp cvar for the session to remember order and location
-	if( !trap_Cvar_VariableValue("ui_sortmethod") )
-	{
-		trap_Cvar_SetValue("ui_sortmethod", 1);
-		trap_Cvar_SetValue( "ui_sortmethod_direction", 0 );
-	}
 	UI_SetupSpinControl( menuitem, sort_ping, trap_Cvar_VariableValue("ui_sortmethod_direction") );
 	menuitem->sort_active = trap_Cvar_VariableValue("ui_sortmethod");
 	menuitem->sort_type = SORT_PING;
