@@ -281,42 +281,37 @@ const char *Default_MenuKey( menuframework_s *m, int key )
 		return menu_out_sound;
 
 	case K_MOUSE1:
-		if( m && (m_cursoritem == item) && Menu_SlideItem( m, 1, key ) )
-		{
-			sound = menu_move_sound;
-		}
-		else
-		{
-			if( m )
-				Menu_SelectItem( m );
-			sound = menu_move_sound;
-		}
+		if( !Menu_SlideItem( m, 1, key ) )
+			Menu_SelectItem( m );
+		sound = menu_move_sound;
 		break;
 
 	case K_MOUSE2:
-		// wsw : pb : fix ui slider bug
 		if( m && (m_cursoritem == item) && Menu_SlideItem( m, -1, key ) )
-		{
 			sound = menu_move_sound;
-		}
 		else
 		{
 			M_PopMenu ();
 			sound = menu_out_sound;
-	}
+		}
 		break;
 
 	case K_MWHEELUP:
 		if ( Menu_ItemAtCursor(m)->scrollbar_id ) //sliding a scrollbar moves 3 lines
-			Menu_SlideItem( m, -3, key );
-		else if ( Menu_ItemAtCursor(m)->type == MTYPE_SPINCONTROL ) //sliding a spingcontrol moves 1 item
-			Menu_SlideItem( m, -1, key );
+			Menu_SlideItem( m, -3, key ); //scrolling up is the equivalent of sliding left, therefore inverted.
+		else if ( Menu_ItemAtCursor(m)->type == MTYPE_SPINCONTROL || Menu_ItemAtCursor(m)->type == MTYPE_SLIDER ) //sliding a spincontrol moves 1 item
+			Menu_SlideItem( m, 1, key );
 		break;
 	case KP_UPARROW:
 	case K_UPARROW:
 		if ( m )
 		{
-			m->cursor--;
+			menucommon_t *item = Menu_ItemAtCursor(m);
+			menucommon_t *scroll = m->items[item->scrollbar_id];
+			if ( item->scrollbar_id && item->type == MTYPE_ACTION && item->localdata[0] == 0 && scroll->curvalue > 0)
+				Menu_SlideItem( m, -1, key );
+			else
+				m->cursor--;
 			Menu_AdjustCursor( m, -1 );
 			sound = menu_move_sound;
 		}
@@ -324,7 +319,21 @@ const char *Default_MenuKey( menuframework_s *m, int key )
 	case K_TAB:
 		if ( m )
 		{
-			m->cursor++;
+			if ( Menu_ItemAtCursor(m)->scrollbar_id && Menu_ItemAtCursor(m)->type == MTYPE_ACTION )
+			{
+				int i = Menu_ItemAtCursor(m)->scrollbar_id;
+				while ( i <= MAXMENUITEMS )
+				{
+					if ( !m->items[i]->scrollbar_id )
+					{
+						m->cursor = i;
+						break;
+					}
+					i++;
+				}
+			}
+			else
+				m->cursor++;
 			Menu_AdjustCursor( m, 1 );
 			sound = menu_move_sound;
 		}
@@ -332,15 +341,20 @@ const char *Default_MenuKey( menuframework_s *m, int key )
 
 	case K_MWHEELDOWN:
 		if ( Menu_ItemAtCursor(m)->scrollbar_id ) //sliding a scrollbar moves 3 lines
-			Menu_SlideItem( m, 3, key );
-		else if ( Menu_ItemAtCursor(m)->type == MTYPE_SPINCONTROL ) //sliding a spingcontrol moves 1 item
-			Menu_SlideItem( m, 1, key );
+			Menu_SlideItem( m, 3, key ); //scrolling down is the equivalent of sliding right, therefore inverted.
+		else if ( Menu_ItemAtCursor(m)->type == MTYPE_SPINCONTROL || Menu_ItemAtCursor(m)->type == MTYPE_SLIDER ) //sliding a spincontrol moves 1 item
+			Menu_SlideItem( m, -1, key );
 		break;
 	case KP_DOWNARROW:
 	case K_DOWNARROW:
 		if ( m )
 		{
-			m->cursor++;
+			menucommon_t *item = Menu_ItemAtCursor(m);
+			menucommon_t *scroll = m->items[item->scrollbar_id];
+			if ( item->scrollbar_id && item->type == MTYPE_ACTION && m->items[m->cursor + 1]->scrollbar_id != item->scrollbar_id && scroll->curvalue < scroll->maxvalue )
+				Menu_SlideItem( m, 1, key );
+			else
+				m->cursor++;
 			Menu_AdjustCursor( m, 1 );
 			sound = menu_move_sound;
 		}
@@ -636,6 +650,9 @@ UI_MouseMove
 */
 void UI_MouseMove( int dx, int dy )
 {
+	if( uis.bind_grab )
+		return; //don't move the mouse if we're grabbing binds
+
 	uis.cursorX += dx;
 	uis.cursorY += dy;
 
@@ -761,8 +778,9 @@ void UI_Refresh( unsigned int time, int clientState, int serverState, qboolean b
 	m_drawfunc();
 
 	// draw cursor
-	trap_R_DrawStretchPic( uis.cursorX - 16, uis.cursorY - 16, 32, 32, 
-		0, 0, 1, 1, colorWhite, trap_R_RegisterPic( UI_SHADER_CURSOR ) );
+	if (!uis.bind_grab)
+		trap_R_DrawStretchPic( uis.cursorX - 16, uis.cursorY - 16, 32, 32, 
+			0, 0, 1, 1, colorWhite, trap_R_RegisterPic( UI_SHADER_CURSOR ) );
 
 	// delay playing the enter sound until after the
 	// menu has been drawn, to avoid delay while
