@@ -263,7 +263,7 @@ static char *KeysymToKey(KeySym keysym)
 	// wsw : mdr
 	case XK_Caps_Lock: return "K_CAPSLOCK";
 	case XK_Num_Lock: return "K_NUMLOCK";
-	case XK_Scroll_Lock: return "K_SCROLLLOCK";
+	case XK_Scroll_Lock: return "K_SCROLLOCK";
 	}
 
 	buf = XKeysymToString(keysym);
@@ -479,7 +479,7 @@ static char *XLateKey(XKeyEvent *ev, int *key)
 	// wsw : mdr
 	case XK_Caps_Lock: *key = K_CAPSLOCK; break;
 	case XK_Num_Lock: *key = K_NUMLOCK; break;
-	case XK_Scroll_Lock: *key = K_SCROLLLOCK; break;
+	case XK_Scroll_Lock: *key = K_SCROLLOCK; break;
 
 	default:
 		if (XLookupRet == 0)
